@@ -54,11 +54,11 @@ class VideoVariable(Variable):
         ('radeon', _("AMD Radeon (radeon)")),
         ('amdgpu', _("AMD AMDGPU (amdgpu)")),
         ('fglrx', _("AMD Catalyst (fglrx)")),
-        ('intel', _("Intel (intel)")),
         ('modesetting', _("Framebuffer device (modesetting)")),
+        ('vesa', _("Generic VESA (vesa)")),
+        ('intel', _("Intel (intel)")),
         ('nouveau', _("Nvidia Nouveau (nouveau)")),
         ('nvidia', _("Nvidia Graphics Driver (nvidia)")),
-        ('vesa', _("Generic VESA (vesa)")),
     ])
 
     def uncompatible(self):
@@ -164,7 +164,7 @@ class VariableOsInstallX11VideoAvailable(VideoVariable):
     # supported = ["nvidia", "fglrx", "amdgpu", "nouveau", "intel", "radeon"]
     supported = ["nvidia", "fglrx", "amdgpu",
                  "modesetting",
-                 "nouveau", "intel", "radeon"]
+                 "nouveau", "intel", "radeon", "vesa"]
 
     def get(self):
         image = self.Get('cl_image')
